@@ -9,7 +9,7 @@
 #
 package MooseX::Attribute::Deflator::Moose;
 {
-  $MooseX::Attribute::Deflator::Moose::VERSION = '2.1.10'; # TRIAL
+  $MooseX::Attribute::Deflator::Moose::VERSION = '2.1.11'; # TRIAL
 }
 
 # ABSTRACT: Deflators for Moose type constraints
@@ -25,8 +25,8 @@ inflate [qw(ArrayRef HashRef)], via { JSON::decode_json($_) },
 deflate 'ScalarRef', via {$$_}, inline_as {'$$value'};
 inflate 'ScalarRef', via { \$_ }, inline_as {'\$value'};
 
-deflate 'Bool', via { $_ ? JSON::XS::true : JSON::XS::false },
-    inline_as {'$value ? JSON::XS::true : JSON::XS::false'};
+deflate 'Bool', via { $_ ? JSON::true : JSON::false },
+    inline_as {'$value ? JSON::true : JSON::false'};
 inflate 'Bool', via { $_ ? 1 : 0 }, inline_as {'$value ? 1 : 0'};
 
 deflate 'Item', via {$_}, inline_as {'$value'};
@@ -42,19 +42,17 @@ deflate 'HashRef[]', via {
     return $deflate->( $value, $constraint->parent );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent    = $deflators->( $constraint->parent );
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n",
+    return (
         '$value = {%$value};',
         'while ( my ( $k, $v ) = each %$value ) {',
         '$value->{$k} = do {',
         '    my $value = $value->{$k};',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_parameter ),
         '    };',
         '  };',
         '}',
-        $parent,
+        $deflators->( $constraint->parent ),
     );
 };
 
@@ -68,17 +66,15 @@ inflate 'HashRef[]', via {
     return $value;
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent    = $deflators->( $constraint->parent );
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n",
+    return (
         '$value = do {',
-        $parent,
+        $deflators->( $constraint->parent ),
         ' };',
         'while ( my ( $k, $v ) = each %$value ) {',
         '  $value->{$k} = do {',
         '    my $value = $value->{$k};',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_parameter ),
         '    };',
         '  };',
         '}',
@@ -93,19 +89,17 @@ deflate 'ArrayRef[]', via {
     return $deflate->( $value, $constraint->parent );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent    = $deflators->( $constraint->parent );
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n",
+    return (
         '$value = [@$value];',
         'for( @$value ) {',
         '  $_ = do {',
         '    my $value = $_;',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_parameter ),
         '    };',
         '  };',
         '}',
-        $parent,
+        $deflators->( $constraint->parent ),
     );
 };
 
@@ -116,17 +110,15 @@ inflate 'ArrayRef[]', via {
     return $value;
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent    = $deflators->( $constraint->parent );
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n",
+    return (
         '$value = do {',
-        $parent,
+        $deflators->( $constraint->parent ),
         ' };',
         'for( @$value ) {',
         '  $_ = do {',
         '    my $value = $_;',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_parameter ),
         '    };',
         '  };',
         '}',
@@ -156,7 +148,7 @@ deflate 'ScalarRef[]', via {
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
     my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n", '$value = do {', $parameter, '};', '$$value' );
+    return ( '$value = do {', $parameter, '};', '$$value' );
 };
 
 inflate 'ScalarRef[]', via {
@@ -165,7 +157,7 @@ inflate 'ScalarRef[]', via {
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
     my $parameter = $deflators->( $constraint->type_parameter );
-    return join( "\n", '$value = do {', $parameter, '};', '\$value' );
+    return ( '$value = do {', $parameter, '};', '\$value' );
 };
 
 1;
@@ -180,7 +172,7 @@ MooseX::Attribute::Deflator::Moose - Deflators for Moose type constraints
 
 =head1 VERSION
 
-version 2.1.10
+version 2.1.11
 
 =head1 SYNOPSIS
 
