@@ -9,7 +9,7 @@
 #
 package MooseX::Attribute::Deflator::Structured;
 {
-  $MooseX::Attribute::Deflator::Structured::VERSION = '2.1.10'; # TRIAL
+  $MooseX::Attribute::Deflator::Structured::VERSION = '2.1.11'; # TRIAL
 }
 
 # ABSTRACT: Deflators for MooseX::Types::Structured
@@ -21,8 +21,7 @@ deflate 'MooseX::Types::Structured::Optional[]', via {
     return $deflate->( $_, $constraint->type_parameter );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return $parameter;
+    return $deflators->( $constraint->type_parameter );
 };
 
 inflate 'MooseX::Types::Structured::Optional[]', via {
@@ -30,8 +29,7 @@ inflate 'MooseX::Types::Structured::Optional[]', via {
     return $inflate->( $_, $constraint->type_parameter );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parameter = $deflators->( $constraint->type_parameter );
-    return $parameter;
+    return $deflators->( $constraint->type_parameter );
 };
 
 deflate 'MooseX::Types::Structured::Map[]', via {
@@ -44,19 +42,17 @@ deflate 'MooseX::Types::Structured::Map[]', via {
     return $deflate->( $value, $constraint->parent );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent    = $deflators->( $constraint->parent );
-    my $parameter = $deflators->( $constraint->type_constraints->[1] );
-    return join( "\n",
+    return (
         '$value = {%$value};',
         'while ( my ( $k, $v ) = each %$value ) {',
         '$value->{$k} = do {',
         '    my $value = $value->{$k};',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_constraints->[1] ),
         '    };',
         '  };',
         '}',
-        $parent,
+        $deflators->( $constraint->parent ),
     );
 };
 
@@ -70,18 +66,15 @@ inflate 'MooseX::Types::Structured::Map[]', via {
     return $value;
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent = $deflators->( $constraint->parent );
-    my $parameter
-        = $deflators->( $constraint->type_constraints->[1] );
-    return join( "\n",
+    return (
         '$value = do {',
-        $parent,
+        $deflators->( $constraint->parent ),
         ' };',
         'while ( my ( $k, $v ) = each %$value ) {',
         '  $value->{$k} = do {',
         '    my $value = $value->{$k};',
         '    $value = do {',
-        $parameter,
+        $deflators->( $constraint->type_constraints->[1] ),
         '    };',
         '  };',
         '}',
@@ -99,7 +92,6 @@ deflate 'MooseX::Types::Structured::Dict[]', via {
     return $deflate->( $value, $constraint->parent );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent      = $deflators->( $constraint->parent );
     my %constraints = @{ $constraint->type_constraints };
     my @map         = 'my $dict;';
     while ( my ( $k, $v ) = each %constraints ) {
@@ -108,7 +100,7 @@ deflate 'MooseX::Types::Structured::Dict[]', via {
             'my $value = shift;',
             $deflators->($v), ' };' );
     }
-    return join( "\n",
+    return (
         @map,
         '$value = {%$value};',
         'while ( my ( $k, $v ) = each %$value ) {',
@@ -117,7 +109,7 @@ deflate 'MooseX::Types::Structured::Dict[]', via {
         '    $value = $dict->{$k}->($value);',
         '  };',
         '}',
-        $parent,
+        $deflators->( $constraint->parent ),
     );
 };
 
@@ -131,7 +123,6 @@ inflate 'MooseX::Types::Structured::Dict[]', via {
     return $value;
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent      = $deflators->( $constraint->parent );
     my %constraints = @{ $constraint->type_constraints };
     my @map         = 'my $dict;';
     while ( my ( $k, $v ) = each %constraints ) {
@@ -140,10 +131,10 @@ inflate 'MooseX::Types::Structured::Dict[]', via {
             'my $value = shift;',
             $deflators->($v), ' };' );
     }
-    return join( "\n",
+    return (
         @map,
         '$value = do {',
-        $parent,
+        $deflators->( $constraint->parent ),
         ' };',
         'while ( my ( $k, $v ) = each %$value ) {',
         '$value->{$k} = do {',
@@ -153,7 +144,7 @@ inflate 'MooseX::Types::Structured::Dict[]', via {
         '}',
         '$value',
     );
-};;
+};
 
 deflate 'MooseX::Types::Structured::Tuple[]', via {
     my ( $attr, $constraint, $deflate ) = @_;
@@ -166,7 +157,6 @@ deflate 'MooseX::Types::Structured::Tuple[]', via {
     return $deflate->( $value, $constraint->parent );
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent      = $deflators->( $constraint->parent );
     my @constraints = @{ $constraint->type_constraints };
     my @map         = 'my $tuple = [];';
     foreach my $tc (@constraints) {
@@ -175,7 +165,7 @@ deflate 'MooseX::Types::Structured::Tuple[]', via {
             'my $value = shift;',
             $deflators->($tc), ' });' );
     }
-    return join( "\n",
+    return (
         @map,
         '$value = [@$value];',
         'for ( my $i = 0; $i < @$value; $i++ ) {',
@@ -184,7 +174,7 @@ deflate 'MooseX::Types::Structured::Tuple[]', via {
         '    $value = ($tuple->[$i] || $tuple->[-1])->($value);',
         '  };',
         '}',
-        $parent,
+        $deflators->( $constraint->parent ),
     );
 };
 
@@ -199,7 +189,6 @@ inflate 'MooseX::Types::Structured::Tuple[]', via {
     return $value;
 }, inline_as {
     my ( $attr, $constraint, $deflators ) = @_;
-    my $parent      = $deflators->( $constraint->parent );
     my @constraints = @{ $constraint->type_constraints };
     my @map         = 'my $tuple = [];';
     foreach my $tc (@constraints) {
@@ -208,10 +197,10 @@ inflate 'MooseX::Types::Structured::Tuple[]', via {
             'my $value = shift;',
             $deflators->($tc), ' });' );
     }
-    return join( "\n",
+    return (
         @map,
         '$value = do {',
-        $parent,
+        $deflators->( $constraint->parent ),
         ' };',
         'for ( my $i = 0; $i < @$value; $i++ ) {',
         '$value->[$i] = do {',
@@ -235,7 +224,7 @@ MooseX::Attribute::Deflator::Structured - Deflators for MooseX::Types::Structure
 
 =head1 VERSION
 
-version 2.1.10
+version 2.1.11
 
 =head1 SYNOPSIS
 
